#
# spec file for package frr
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2019, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with     cumulus
%bcond_with     datacenter
%bcond_with     mininet

%define skip_python2 1

%define frr_user frr
%define frr_group frr
%define frrvty_group frrvty
%define frr_home %{_localstatedir}/lib/%{name}
%define frr_statedir %{_rundir}/%{name}
%define frr_daemondir %{_prefix}/lib/frr

Name:           frr
Version:        7.4
Release:        150300.4.20.1
Summary:        FRRouting Routing daemon
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Networking/System
URL:            https://www.frrouting.org
#Git-Clone:     https://github.com/FRRouting/frr.git
Source:         https://github.com/FRRouting/frr/archive/%{name}-%{version}.tar.gz
Source1:        %{name}-tmpfiles.d
Patch1:		0001-disable-zmq-test.patch
Patch3:         0003-babeld-fix-10487-by-adding-a-check-on-packet-length.patch
Patch4:         0004-babeld-fix-10502-10503-by-repairing-the-checks-on-le.patch
Patch5:         0005-isisd-fix-router-capability-TLV-parsing-issues.patch
Patch6:         0006-isisd-fix-10505-using-base64-encoding.patch
Patch7:         0007-bgpd-Make-sure-hdr-length-is-at-a-minimum-of-what-is.patch
Patch8:         0008-isisd-Ensure-rcap-is-freed-in-error-case.patch
Patch9:         0009-tools-Use-install-instead-of-touch-chown-combination.patch
Patch10:        0010-tools-Run-as-FRR_USER-install-chown-commands-to-avoi.patch
Patch11:        0011-bgpd-avoid-notify-race-between-io-and-main-pthreads.patch
Patch12:        0012-bgpd-Do-not-process-NLRIs-if-the-attribute-length-is.patch
Patch13:        0013-bgpd-Use-treat-as-withdraw-for-tunnel-encapsulation-.patch
Patch14:        0014-bgpd-Limit-flowspec-to-no-attribute-means-a-implicit.patch
Patch15:        0015-bgpd-Check-mandatory-attributes-more-carefully-for-U.patch
Patch16:        0016-bgpd-Handle-MP_REACH_NLRI-malformed-packets-with-ses.patch
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison >= 2.7
BuildRequires:  flex
BuildRequires:  libtool
BuildRequires:  libyang-extentions
BuildRequires:  makeinfo
%if %{with mininet}
BuildRequires:  mininet
%endif
BuildRequires:  net-snmp-devel
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  readline-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(grpc)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(libcares)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libprotobuf-c)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libyang) >= 1.0.101
BuildRequires:  pkgconfig(libzmq) >= 4.0.0
BuildRequires:  pkgconfig(rtrlib) >= 0.5.0
BuildRequires:  pkgconfig(sqlite3)
Requires(post): %{install_info_prereq}
Requires(pre):  %{install_info_prereq}
Requires(pre):  shadow
Requires(preun): %{install_info_prereq}
# /usr/bin/install
Requires:       coreutils
# /usr/bin/su
Requires:       util-linux
Recommends:     logrotate
Conflicts:      quagga
Provides:       zebra = %{version}
Obsoletes:      zebra < %{version}
Requires:       libyang-extentions

%description
FRR is free software which manages TCP/IP based routing protocols.
It supports BGP4, BGP4+, OSPFv2, OSPFv3, IS-IS, RIPv1, RIPv2, RIPng,
PIM and LDP as well as the IPv6 versions of these.

FRR is a fork of Quagga..

%package -n libfrrfpm_pb0
Summary:        FRRouting fpm protobuf library
Group:          System/Libraries

%description -n libfrrfpm_pb0
This library contains forwarding plane manager protobuf definitions
for FRRouting.

%package -n libfrr_pb0
Summary:        FRRouting protobuf library
Group:          System/Libraries

%description -n libfrr_pb0
This library contains protobuf memory management for FRRouting..

%package -n libfrrgrpc_pb0
Summary:        FRRouting grpc protobuf library
Group:          System/Libraries

%description -n libfrrgrpc_pb0
This library contains grpc protobuf definitions for FRRouting.

%package -n libfrrospfapiclient0
Summary:        API for FRRouting's OSPFv2 implementation
Group:          System/Libraries

%description -n libfrrospfapiclient0
This library contains part of the OSPFv2 implementation of FRRouting.

%package -n libfrrsnmp0
Summary:        FRRouting snmp library
Group:          System/Libraries

%description -n libfrrsnmp0
This library contains part of the net-snmp agentx implementation of FRRouting.

%package -n libfrrzmq0
Summary:        FRRouting zeromq library
Group:          System/Libraries

%description -n libfrrzmq0
This library contains part of the zermomq implementation of FRRouting.

%package -n libfrr0
Summary:        FRRouting utility library
Group:          System/Libraries

%description -n libfrr0
This library contains various utility functions to FRRouting, such as
data types, buffers and socket handling.

%package -n libfrrcares0
Summary:        FRRouting utility library
Group:          System/Libraries

%description -n libfrrcares0
This library contains various utility functions to FRRouting, such as
data types, buffers and socket handling.

%package -n libmlag_pb0
Summary:        FRRouting utility library
Group:          System/Libraries

%description -n libmlag_pb0
This library contains part of the mlag implementation of FRRouting.

%package devel
Summary:        Header and object files for frr development
Group:          Development/Libraries/C and C++
Requires:       libfrr0 = %{version}
Requires:       libfrr_pb0 = %{version}
Requires:       libfrrcares0 = %{version}
Requires:       libfrrfpm_pb0 = %{version}
Requires:       libfrrgrpc_pb0 = %{version}
Requires:       libfrrospfapiclient0 = %{version}
Requires:       libfrrsnmp0 = %{version}
Requires:       libfrrzmq0 = %{version}
Requires:       libmlag_pb0 = %{version}

%description devel
The frr-devel package contains the header and object files necessary for
developing OSPF-API and frr applications.

%prep
%setup -q -n %{name}-%{name}-%{version}
%patch1 -p1
%patch3 -p1
%patch4 -p1
gzip -d tests/isisd/test_fuzz_isis_tlv_tests.h.gz
%patch5 -p1
gzip -9 tests/isisd/test_fuzz_isis_tlv_tests.h
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1

%build
# GCC LTO objects must be "fat" to avoid assembly errors
export CFLAGS="-ffat-lto-objects"

autoreconf -fiv
%configure \
    --disable-silent-rules \
    --enable-exampledir=%{_docdir}/%{name}/examples \
    --sysconfdir=%{_sysconfdir}/%{name} \
    --localstatedir=%{frr_statedir} \
    --sbindir=%{frr_daemondir} \
    --with-moduledir=%{_libdir}/frr/modules \
    --disable-static \
    --with-vtysh-pager=%{_bindir}/less \
    --enable-user=%{frr_user} \
    --enable-group=%{frr_group} \
    --enable-vty-group=%{frrvty_group} \
    --enable-configfile-mask=0640 \
    --enable-logfile-mask=0640 \
    --enable-doc \
    --enable-doc-html \
    --enable-babeld \
    --enable-bfdd \
    --enable-bgpd \
    --enable-bgp-vnc \
%if %{with cumulus}
    --enable-cumulus \
%endif
%if %{with datacenter}
    --enable-datacenter \
%endif
    --enable-eigrpd \
    --enable-fpm \
    --enable-irdp \
    --enable-isisd \
    --enable-ldpd \
    --enable-multipath=256 \
    --enable-nhrpd \
    --enable-snmp \
    --enable-zeromq \
    --enable-ospfd \
    --enable-ospf6d \
    --enable-ospfapi \
    --enable-ospfclient \
    --with-libpam \
    --enable-pbrd \
    --enable-pimd \
    --enable-protobuf \
    --enable-ripd \
    --enable-ripngd \
    --enable-rpki \
    --enable-rtadv \
    --enable-sharpd \
    --enable-staticd \
    --enable-vtysh \
    --enable-watchfrr \
    --enable-zebra \
    --enable-realms \
    --enable-shell-access \
    --with-crypto=openssl \
    --enable-config-rollbacks \
    --enable-grpc \
    --enable-systemd

make %{?_smp_mflags} MAKEINFO="makeinfo --no-split"

%install
make DESTDIR=%{buildroot} INSTALL="install -p" CP="cp -p" install
perl -p -i -e 's|#!/usr/bin/python|#!/usr/bin/python3|g' %{buildroot}/usr/lib/frr/{frr-reload.py,generate_support_bundle.py}

find %{buildroot} -type f -name "*.la" -delete -print

install -d %{buildroot}%{_sysconfdir}/frr
install -d %{buildroot}/%{_docdir}/%{name}
mv %{buildroot}/%{_datadir}/doc/frr/html %{buildroot}/%{_docdir}/%{name}

# remove stray buildinfo files
find %{buildroot}/%{_docdir}/%{name} -type f -name .buildinfo -delete

# systemd init scripts
install -D -m 0644 tools/frr.service %{buildroot}%{_unitdir}/frr.service
install -D -m 0644 tools%{_sysconfdir}/frr/daemons %{buildroot}%{_sysconfdir}/frr/daemons

# add rpki module to daemon
sed -i -e 's/^\(bgpd_options=\)\(.*\)\(".*\)/\1\2 -M rpki\3/' %{buildroot}%{_sysconfdir}/frr/daemons

install -D -m 0644 redhat/frr.pam %{buildroot}%{_sysconfdir}/pam.d/frr
install -D -m 0644 redhat/frr.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/frr

install -d -m 0750 %{buildroot}%{rundir}
install -d -m 0750 %{buildroot}%{_localstatedir}/log/frr
install -D -m 0644 %{SOURCE1} %{buildroot}/%{_tmpfilesdir}/%{name}.conf
sed -e "s|@frr_statedir@|%{frr_statedir}|g" -i %{buildroot}/%{_tmpfilesdir}/%{name}.conf

install -d %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcfrr
rm -f %{buildroot}%{frr_daemondir}/ssd

cat > %{buildroot}%{_sysconfdir}/frr/frr.conf << __EOF__
!hostname frr

!password frr
!enable password frr

log file %{_localstatedir}/log/frr/frr.log
__EOF__
cat > %{buildroot}%{_sysconfdir}/frr/vtysh.conf << __EOF__
! vtysh is using PAM authentication allowing root to use it.
__EOF__

%check
make %{?_smp_mflags} -C tests

%pre
# Create frr user/groups
getent group %{frr_group} >/dev/null || groupadd -r %{frr_group}
getent group %{frrvty_group} >/dev/null || groupadd -r %{frrvty_group}
getent passwd %{frr_user} >/dev/null || useradd -r -g %{frr_group} -G %{frrvty_group} -d %{frr_home} -s /sbin/nologin -c "FRRouting suite" %{frr_user}

%service_add_pre %{name}.service

%post
%service_add_post %{name}.service
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf || true

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service
%install_info_delete --info-dir=%{_infodir} %{_infodir}/frr.info%{ext_info}

%post   -n libfrr_pb0 -p /sbin/ldconfig
%postun -n libfrr_pb0 -p /sbin/ldconfig
%post   -n libfrrgrpc_pb0 -p /sbin/ldconfig
%postun -n libfrrgrpc_pb0 -p /sbin/ldconfig
%post   -n libfrrfpm_pb0 -p /sbin/ldconfig
%postun -n libfrrfpm_pb0 -p /sbin/ldconfig

%post   -n libfrrospfapiclient0 -p /sbin/ldconfig
%postun -n libfrrospfapiclient0 -p /sbin/ldconfig

%post   -n libfrrsnmp0 -p /sbin/ldconfig
%postun -n libfrrsnmp0 -p /sbin/ldconfig

%post   -n libfrrzmq0 -p /sbin/ldconfig
%postun -n libfrrzmq0 -p /sbin/ldconfig

%post   -n libfrr0 -p /sbin/ldconfig
%postun -n libfrr0 -p /sbin/ldconfig

%post   -n libfrrcares0 -p /sbin/ldconfig
%postun -n libfrrcares0 -p /sbin/ldconfig

%post   -n libmlag_pb0 -p /sbin/ldconfig
%postun -n libmlag_pb0 -p /sbin/ldconfig

%files
%license COPYING COPYING-LGPLv2.1
%doc README.md
%doc doc/mpls
%doc %{_docdir}/%{name}/examples
%dir %attr(750,%{frr_user},%{frr_user}) %{_sysconfdir}/%{name}
%config(noreplace) %attr(640,%{frr_user},%{frr_group}) %{_sysconfdir}/%{name}/[!v]*.conf*
%config(noreplace) %attr(640,%{frr_user},%{frrvty_group}) %{_sysconfdir}/%{name}/vtysh.conf
%config(noreplace) %%attr(640,%{frr_user},%{frr_group}) %{_sysconfdir}/%{name}/daemons
%config(noreplace) %{_sysconfdir}/pam.d/frr
%config(noreplace) %{_sysconfdir}/logrotate.d/frr
%{_infodir}/frr.info%{?ext_info}
%{_mandir}/man?/*
%{_docdir}/%{name}/html
%{_unitdir}/%%{name}.service
%dir %{_tmpfilesdir}
%{_tmpfilesdir}/%{name}.conf
%dir %attr(-,%{frr_user},%{frr_group}) %{_localstatedir}/log/frr
%dir %attr(-,%{frr_user},%{frr_group}) %ghost %{frr_statedir}
%{_sbindir}/rc%{name}
%dir %{_prefix}/lib/frr
%{_prefix}/lib/frr/fabricd
%{_prefix}/lib/frr/vrrpd
%{_datadir}/yang
%{_bindir}/mtracebis
%{_bindir}/vtysh
%{frr_daemondir}/babeld
%{frr_daemondir}/bfdd
%{frr_daemondir}/bgpd
%{frr_daemondir}/eigrpd
%{frr_daemondir}/frr
%{frr_daemondir}/frr-reload
%{frr_daemondir}/frr-reload.py
%{frr_daemondir}/frrcommon.sh
%{frr_daemondir}/frrinit.sh
%{frr_daemondir}/isisd
%{frr_daemondir}/ldpd
%{frr_daemondir}/nhrpd
%{frr_daemondir}/ospf6d
%{frr_daemondir}/ospfd
%{frr_daemondir}/pbrd
%{frr_daemondir}/pimd
%{frr_daemondir}/ripd
%{frr_daemondir}/ripngd
%{frr_daemondir}/sharpd
%{frr_daemondir}/staticd
%{frr_daemondir}/watchfrr
%{frr_daemondir}/watchfrr.sh
%{frr_daemondir}/zebra
%dir %{_libdir}/frr
%dir %{_libdir}/frr/modules
%{_libdir}/frr/modules/zebra_cumulus_mlag.so
%{_libdir}/frr/modules/zebra_fpm.so
%{_libdir}/frr/modules/zebra_irdp.so
%{_libdir}/frr/modules/bgpd_rpki.so
%{_libdir}/frr/modules/grpc.so
%{_libdir}/frr/modules/dplane_fpm_nl.so
%{_libdir}/frr/modules/bgpd_bmp.so
%{_prefix}/lib/frr/generate_support_bundle.py

%files -n libfrr_pb0
%{_libdir}/libfrr_pb.so.0*

%files -n libfrrfpm_pb0
%{_libdir}/libfrrfpm_pb.so.0*

%files -n libfrrgrpc_pb0
%{_libdir}/libfrrgrpc_pb.so.0*

%files -n libfrrospfapiclient0
%{_libdir}/libfrrospfapiclient.so.0*

%files -n libfrrsnmp0
%{_libdir}/libfrrsnmp.so.0*
%{_libdir}/frr/modules/*_snmp.so

%files -n libfrrzmq0
%{_libdir}/libfrrzmq.so.0*

%files -n libfrr0
%{_libdir}/libfrr.so.0*

%files -n libfrrcares0
%{_libdir}/libfrrcares.so.0*

%files -n libmlag_pb0
%{_libdir}/libmlag_pb.so.0*

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%dir %{_includedir}/%{name}/ospfd
%{_includedir}/%{name}/ospfd/*.h
%dir %{_includedir}/%{name}/ospfapi
%{_includedir}/%{name}/ospfapi/*.h
%dir %{_includedir}/%{name}/eigrpd
%{_includedir}/%{name}/eigrpd/*.h
%{_libdir}/lib*.so

%changelog
* Mon Oct 30 2023 mt@suse.com
- Apply upstream fix for a crash due to a crafted BGP UPDATE message
  (CVE-2023-46753,bsc#1216626,https://github.com/FRRouting/frr/pull/14655/commits/21418d64af11553c402f932b0311c812d98ac3e4).
  [+ 0015-bgpd-Check-mandatory-attributes-more-carefully-for-U.patch]
- Apply upstream fix for a crash due to mishandled malformed
  MP_REACH_NLRI data (CVE-2023-46752,bsc#1216627,https://github.com/FRRouting/frr/pull/14645/commits/b08afc81c60607a4f736f418f2e3eb06087f1a35).
  [+ 0016-bgpd-Handle-MP_REACH_NLRI-malformed-packets-with-ses.patch]
* Tue Sep 12 2023 mt@suse.com
- Apply upstream fix for NULL pointer dereference due to processing
  of malformed requests with no attributes in bgp_nlri_parse_flowspec
  (CVE-2023-41909,bsc#1215065,https://github.com/FRRouting/frr/pull/13222/commits/cfd04dcb3e689754a72507d086ba3b9709fc5ed8).
  [+ 0014-bgpd-Limit-flowspec-to-no-attribute-means-a-implicit.patch]
* Fri Sep  1 2023 mt@suse.com
- Removed protobuf-c BuildRequires (source package name) breaking
  build-system setup with libprotobuf-c-devel 1.3.2 updates.
- Apply upstream fix for bgpd: Do not process NLRIs if the attribute
  length is zero (CVE-2023-41358,bsc#1214735,
  https://github.com/FRRouting/frr/pull/14260)
  [+ 0012-bgpd-Do-not-process-NLRIs-if-the-attribute-length-is.patch]
- Apply upstream fix bgpd: Use treat-as-withdraw for tunnel encapsulation
  attribute instead of session reset (CVE-2023-38802,bsc#1213284,
  https://github.com/FRRouting/frr/pull/14290)
  [+ 0013-bgpd-Use-treat-as-withdraw-for-tunnel-encapsulation-.patch]
* Wed Nov  2 2022 mt@suse.com
- Applied upstream fix for a possible use-after-free due to a race
  condition related to bgp_notify_send_with_data() and
  bgp_process_packet() in bgp_packet.c. This could lead to Remote
  Code Execution or Information Disclosure by sending crafted BGP
  packets (CVE-2022-37035,bsc#1202085).
  [+ 0011-bgpd-avoid-notify-race-between-io-and-main-pthreads.patch]
- Apply upstream fixes for frrinit.sh to avoid a privilege escalation
  from frr to root in frr config creation (bsc#1204124,CVE-2022-42917).
  [+ 0009-tools-Use-install-instead-of-touch-chown-combination.patch,
  + 0010-tools-Run-as-FRR_USER-install-chown-commands-to-avoi.patch]
* Mon Sep  5 2022 mt@suse.com
- Apply upstream fix for out-of-bounds read in the BGP daemon
  that may lead to information disclosure or denial of service
  (bsc#1202023,CVE-2022-37032)
  [+ 0007-bgpd-Make-sure-hdr-length-is-at-a-minimum-of-what-is.patch]
- Apply upstream fix for a memory leak in the IS-IS daemon that
  may lead to server memory exhaustion (bsc#1202022,CVE-2019-25074)
  [+ 0008-isisd-Ensure-rcap-is-freed-in-error-case.patch]
* Mon Mar  7 2022 mt@suse.com
- Apply backport fix for a buffer overflow in isisd due to the use of strdup
  with a non-zero-terminated binary string (bsc#1196506,CVE-2022-26126)
  [+ 0006-isisd-fix-10505-using-base64-encoding.patch]
- Apply backport fix for a buffer overflow in isisd due to wrong checks on
  the input packet length (bsc#1196505,CVE-2022-26125) with workaround
  for the GIT binary patch to tests/isisd/test_fuzz_isis_tlv_tests.h.gz
  [+ 0005-isisd-fix-router-capability-TLV-parsing-issues.patch]
- Apply fix for a buffer overflow in babeld due to wrong checks on
  the input packet length in the packet_examin and subtlv parsing
  (bsc#1196504,bsc#1196507,CVE-2022-26128,CVE-2022-26129)
  [+ 0004-babeld-fix-10502-10503-by-repairing-the-checks-on-le.patch]
- Apply fix for a heap buffer overflow in babeld due to missing check
  on the input packet length (bsc#1196503,CVE-2022-26127)
  [+ 0003-babeld-fix-10487-by-adding-a-check-on-packet-length.patch]
* Fri Apr 23 2021 mt@suse.com
- Use skip, not xfail in 0001-disable-zmq-test.patch to disable
  zmq test as it is not expected to fail but hangs (bsc#1180217)
* Mon Dec 21 2020 rtorreromarijnissen@suse.com
- Disable ZeroMQ tests due to sporadic timeouts during package builds (bsc#1180217)
  [+ 0001-disable-zmq-test.patch]
* Fri Oct  2 2020 mt@suse.com
- add build condition disabling mininet build require by default,
  needed by the optional topology tests.
- removed one occurrence of vrrpd binary listed twice in file list
* Wed Jul  1 2020 mardnh@gmx.de
- Update to version 7.4
  * Upstream does not provide a changelog
- Drop patch (fixed upstream):
  * 0001-build-use-configfile-mode-in-init-script.patch
* Sun May 31 2020 erico.mendonca@suse.com
- 0001-build-use-configfile-mode-in-init-script.patch: Fix CVE-2020-12831 (boo#1171658).
* Wed May  6 2020 mardnh@gmx.de
- Update to version 7.3.1
  Bugfix/maintenance release
  * Upstream does not provide a changelog
* Tue Apr  7 2020 mrueckert@suse.de
- enable verbose make rules
- enable grpc support. new subpackage libfrrgrpc_pb0, new BR:
  pkgconfig(grpc)
- enable config rollbacks. new BR: pkgconfig(sqlite3)
- enable realms support
- enable shell access
- make sure we use system openssl
- fix shebang line of the frr-reload.py and
  generate_support_bundle.py script so we dont pull python2
- do not delete users and groups.
- add Requires for libyang-extentions
* Sat Feb 15 2020 mardnh@gmx.de
- Update to version 7.3
  * Upstream does not provide a changelog this time
- Remove patch:
  * fix_tests.patch (not longer needed)
* Sat Jan 18 2020 mardnh@gmx.de
- Update to version 7.2.1:
  BGPd
  * Fix Addpath issue
  * Do not apply eBGP policy for iBGP peers
  * Show ip and fqdn in json output for show [ip] bgp <route> json
  * Fix large route-distinguisher's format
  * Fix no bgp listen range ... configuration command
  * Autocomplete neighbor for clear bgp
  * Reflect the distance in RIB when it is changed for an
    arbitrary afi/safi
  * Notify "Peer De-configured" after entering 'no neighbor cmd
  * Fix per afi/safi addpath peer counting
  * Rework BGP dampening to be per AFI/SAFI
  * Do not send next-hop as :: in MP_REACH_NLRI if no link-local
    exists
  * Override peer's TTL only if peer-group is configured with TTL
  * Remove error message for unkown afi/safi combination
  * Keep the session down if maximum-prefix is reached
  OSPFd
  * Fix BFD down not tearing down OSPF adjacency for
    point-to-point net
  BFDd
  * Fix multiple VRF handling
  * VRF security improvement
  PIMd
  * Fix rp crash
  NHRPd
  * Make sure no ip nhrp map <something> works as expected
  LDPd
  * Add missing sanity check in the parsing of label messages
  Zebra
  * Use correct state when installing evpn macs
  * Capture dplane plugin flags
  lib
  * Fix interface config when vrf changes
  * Fix Interface Infinite Loop Walk (for special interfaces such
    as bond)
  Others
  * Rename man pages (to avoid conflicts with other packages)
  * Various other fixes for code cleanup and memory leaks
* Fri Jan 17 2020 mardnh@gmx.de
- Fix license tag
* Wed Jan 15 2020 mardnh@gmx.de
- Build with support for pcre, protobuf, rpki and zeromq by default
* Wed Jan 15 2020 idonmez@suse.com
- Cleanup spec file
* Sun Jan 12 2020 mardnh@gmx.de
- Fix build-time dependencies
- Remove superflous comments
* Wed Dec 11 2019 erico.mendonca@suse.com
- fix_tests.patch: correct syntax for Python 3 imports in tests.
- Enabling tests
* Wed Dec 11 2019 erico.mendonca@suse.com
- Update to version frr7.2:
  * zebra: use correct state when installing evpn macs
  * lib: set entry to xpath in if_update_to_new_vrf
  * zebra: capture dplane plugin flags
  * bgpd: Autocomplete neighbor for clear bgp
  * ospfd,eigrpd: don't take address of packed struct member
  * bgpd: Prevent crash in bgp_table_range_lookup
  * bgpd: Fix memory leak in json output of show commands
  * tests: Test if `distance bgp (1-255) (1-255) (1-255)` works
  * bgpd: Reflect the distance in RIB when it is changed for an arbitrary afi/safi
  * bfdd: fix multiple VRF handling
* Tue Dec 10 2019 erico.mendonca@suse.com
- Updating to version 7.2
- Adding systemd scripts
- Fixing build and permission issues
* Tue Jun 18 2019 mardnh@gmx.de
- Update to version 7.0.1
* Sat Feb  2 2019 mardnh@gmx.de
- Initial package, version 6.0.2
